#[repr(u16)]pub enum ErrorStatus {
Show 24 variants
Generic = 1,
OperationNotSupported = 2,
NotSupported = 3,
Corrupted = 4,
InvalidSyscall = 5,
InvalidResource = 6,
InvalidPid = 7,
InvalidOffset = 8,
InvalidPtr = 9,
InvalidStr = 10,
StrTooLong = 11,
InvalidPath = 12,
NoSuchAFileOrDirectory = 13,
NotAFile = 14,
NotADirectory = 15,
AlreadyExists = 16,
NotExecutable = 17,
DirectoryNotEmpty = 18,
MissingPermissions = 19,
MMapError = 20,
Busy = 21,
NotEnoughArguments = 22,
OutOfMemory = 23,
InvalidTid = 24,
}Variants
Generic = 1
use when no ErrorStatus is available for xyz and you cannot add a new one
OperationNotSupported = 2
NotSupported = 3
for example an elf class is not supported, there is a difference between NotSupported and OperationNotSupported
Corrupted = 4
for example a magic value is invalid
InvalidSyscall = 5
InvalidResource = 6
InvalidPid = 7
InvalidOffset = 8
InvalidPtr = 9
instead of panicking syscalls will return this on null and unaligned pointers some operations may accept null pointers
InvalidStr = 10
for operations that requires a valid utf8 str…
StrTooLong = 11
for operations that requires a str that doesn’t exceed a max length such as file names (128 bytes)
InvalidPath = 12
NoSuchAFileOrDirectory = 13
NotAFile = 14
NotADirectory = 15
AlreadyExists = 16
NotExecutable = 17
DirectoryNotEmpty = 18
MissingPermissions = 19
MMapError = 20
Busy = 21
NotEnoughArguments = 22
OutOfMemory = 23
InvalidTid = 24
Invalid Thread ID
Implementations