Module num
safa_
api
0.4.3
Module num
Module Items
Structs
Traits
In safa_
api::
ffi
safa_api
::
ffi
Module
num
Structs

Should
NotBe
Zero
Describes something that is valid when passed as a zero but SHOULDN’T BE a zero
Traits

Zeroable
Thing
Describes a trait for some types that are valid when passed as a zero