ShouldNotBeZero

Struct ShouldNotBeZero 

pub struct ShouldNotBeZero<T>(/* private fields */)
where
    T: ZeroableThing;
Describes something that is valid when passed as a zero but SHOULDN’T BE a zero

mainly for usage with FFI and OptZero so that if it was passed as a zero it would be treated as a None value

Implementations

Source

impl<T> ShouldNotBeZero<T>
where T: ZeroableThing,

pub fn new(value: T) -> Option<ShouldNotBeZero<T>>

pub const unsafe fn new_unchecked(value: T) -> ShouldNotBeZero<T>

pub const fn value_ref(&self) -> &T

Source

impl<T> ShouldNotBeZero<T>
where T: ZeroableThing + Copy,

pub const fn value(&self) -> T