Module ptr

Module ptr 

Structs

FFINonNull
Represents a non-null raw pointer, similar to core::ptr::NonNull, but it instead doesn’t guarantee that the pointer is valid, instead IT SHOULD BE valid, additional checks should be performed before using it.