pub struct FFINonNull<T>(/* private fields */)
where
T: ?Sized;Expand description
Represents a non-null raw pointer, similar to core::ptr::NonNull, but it instead doesn’t guarantee that the pointer is valid,
instead IT SHOULD BE valid, additional checks should be performed before using it.
The purpose is for use alongside crate::ffi::option::OptZero.
Implementations
Sourceimpl<T> FFINonNull<T>where
T: ?Sized,
impl<T> FFINonNull<T>where
T: ?Sized,
Sourcepub const fn new(ptr: *mut T) -> Option<FFINonNull<T>>
pub const fn new(ptr: *mut T) -> Option<FFINonNull<T>>
Creates a new instance of FFINonNull if the pointer is not null otherwise returns None.
Sourcepub const unsafe fn new_unchecked(ptr: *mut T) -> FFINonNull<T>
pub const unsafe fn new_unchecked(ptr: *mut T) -> FFINonNull<T>
Creates a new instance of FFINonNull without checking if the pointer is null.
Safety
The caller must ensure that the pointer is not null.
Sourcepub const fn as_ptr(&self) -> *mut T
pub const fn as_ptr(&self) -> *mut T
Returns the raw pointer stored in this FFINonNull instance.