syscall

Macro syscall 

macro_rules! syscall {
    ($num: expr, $($arg: expr),*) => { ... };
}
Invokes a syscall with the given number and arguments Number must be of type [SyscallNum] Arguments must be of type usize returns a SyscallResult