Module args

Module args 

Wrapper around the arguments passed to the program. api should be initialized before use see super::init

Structs

ArgsIter
An iterator over the arguments passed to the program.

Functions

sysget_arg
Get the argument at the given index.
sysget_argc
Get the number of arguments passed to the program.