Module env

contains functions related to environment variables, api must be initialized before using these functions, see super::init

Functions

env_clear
env_get
env_get_all
Gets all the environment variables in the current process
env_remove
env_set
sysenv_clear
Clear all environment variables.
sysenv_get
Get an environment variable by key.
sysenv_remove
Remove an environment variable by key.
sysenv_set
Set an environment variable by key.