Module init

contains api initialization functions, that should be called before using the api

Functions

_c_api_init
Initializes the safa-api, converts arguments to C-style arguments, calls main, and exits with the result main are designed as C main function,
sysapi_init
Initializes the safa-api if your programs are designed as C main function,