Module stdio

Module stdio 

contains functions related to standard input/output/error streams descriptors api must be initialized before using these functions, see super::init

Functions

init_meta
sysget_stderr
Returns the resource id of the stderr file descriptor
sysget_stdin
Returns the resource id of the stdin file descriptor
sysget_stdout
Returns the resource id of the stdout file descriptor
systry_get_stderr
Returns the resource id of the stderr file descriptor (if available)
systry_get_stdin
Returns the resource id of the stdin file descriptor (if available)
systry_get_stdout
Returns the resource id of the stdout file descriptor (if available)