sysget_stderr

Function sysget_stderr 

#[unsafe(no_mangle)]
pub extern "C" fn sysget_stderr() -> usize
Returns the resource id of the stderr file descriptor

if there is no stderr file descriptor, it will fall back to dev:/tty