sysget_stdin

Function sysget_stdin 

#[unsafe(no_mangle)]
pub extern "C" fn sysget_stdin() -> usize
Returns the resource id of the stdin file descriptor

if there is no stdin file descriptor, it will fall back to dev:/tty