Function sysmeta_stdout

#[no_mangle]
pub extern "C" fn sysmeta_stdout() -> usize
Returns the resource id of the stdout file descriptor

if there is no stdout file descriptor, it will fall back to dev:/tty