Struct OpenOptions

pub struct OpenOptions(/* private fields */);
Describes the options for opening a file or directory.

Implementations

Source

impl OpenOptions

pub const WRITE: OpenOptions

Open the file for writing.

pub const READ: OpenOptions

Open the file for reading.

pub const CREATE_FILE: OpenOptions

Create the file if it does not exist.

pub const CREATE_DIRECTORY: OpenOptions

Create the directory if it does not exist. (doesn’t create parent directories)

pub const WRITE_TRUNCATE: OpenOptions

Truncate the file to zero length if it already exists.

pub const fn from_bits(bits: u8) -> OpenOptions

pub const fn contains(self, other: OpenOptions) -> bool

pub const fn is_write(&self) -> bool

pub const fn is_write_truncate(&self) -> bool

pub const fn is_read(&self) -> bool

pub const fn create_file(&self) -> bool

pub const fn create_dir(&self) -> bool