Struct AbiStructures

#[repr(C)]
pub struct AbiStructures { pub stdio: TaskStdio, }
ABI structures are structures that are passed to tasks by the parent task for now only stdio file descriptors are passed you get a pointer to them in the r8 register at _start (the 5th argument)

Fields

stdio: TaskStdio