#[repr(C)]pub struct PSpawnConfig {
pub revision: u8,
pub name: RawSlice<u8>,
pub argv: RawSliceMut<RawSlice<u8>>,
pub flags: SpawnFlags,
pub stdio: *const TaskStdio,
pub env: RawSliceMut<RawSlice<u8>>,
pub priority: Optional<ContextPriority>,
}Expand description
configuration for the spawn syscall
Fields
revision: u8config version for compatibility added in kernel version 0.2.1 and therefore breaking compatibility with any program compiled for version below 0.2.1 revision 1: added env revision 2: added priority (v0.4.0)
name: RawSlice<u8>argv: RawSliceMut<RawSlice<u8>>flags: SpawnFlagsstdio: *const TaskStdioenv: RawSliceMut<RawSlice<u8>>priority: Optional<ContextPriority>Implementations
Sourceimpl PSpawnConfig
impl PSpawnConfig
pub fn new( name: &str, argv: *mut [&[u8]], env: *mut [&[u8]], flags: SpawnFlags, stdio: &TaskStdio, priority: Option<ContextPriority>, ) -> PSpawnConfig