Struct SpawnConfig

#[repr(C)]
pub struct SpawnConfig { pub version: u8, pub name: RawSlice<u8>, pub argv: RawSliceMut<RawSlice<u8>>, pub flags: SpawnFlags, pub stdio: *const TaskStdio, pub env: RawSliceMut<RawSlice<u8>>, }
configuration for the spawn syscall

Fields

version: u8

config version for compatibility added in kernel version 0.2.1 and therefore breaking compatibility with any program compiled for version below 0.2.1

name: RawSlice<u8>argv: RawSliceMut<RawSlice<u8>>flags: SpawnFlagsstdio: *const TaskStdioenv: RawSliceMut<RawSlice<u8>>

Implementations

Source

impl SpawnConfig

pub fn new( name: &str, argv: *mut [&[u8]], env: *mut [&[u8]], flags: SpawnFlags, stdio: &TaskStdio, ) -> SpawnConfig