Struct TSpawnConfig

#[repr(C)]
pub struct TSpawnConfig { pub revision: u32, pub argument_ptr: *const (), pub priority: Optional<ContextPriority>, pub cpu: Optional<usize>, }
configuration for the thread spawn syscall for now it takes only a single argument pointer which is a pointer to an optional argument, that pointer is going to be passed to the thread as the second argument

Fields

revision: u32argument_ptr: *const ()priority: Optional<ContextPriority>cpu: Optional<usize>

The index of the CPU to append to, if it is None the kernel will choose one, use 0 for the boot CPU

Implementations

Source

impl TSpawnConfig

pub fn into_rust(&self) -> (*const (), Option<ContextPriority>, Option<usize>)

pub fn new( argument_ptr: *const (), priority: Option<ContextPriority>, cpu: Option<usize>, ) -> TSpawnConfig

Create a new thread spawn configuration with the latest revision