pub struct Mutex<T> { /* private fields */ }Implementations
Sourceimpl<T> Mutex<T>
impl<T> Mutex<T>
Sourcepub fn lock(&self) -> MutexGuard<'_, T>
pub fn lock(&self) -> MutexGuard<'_, T>
Locks the mutex, blocking the current thread until it can be acquired.
the Mutex is locked until the returned MutexGuard is dropped.
Sourcepub fn try_lock(&self) -> Option<MutexGuard<'_, T>>
pub fn try_lock(&self) -> Option<MutexGuard<'_, T>>
Attempts to acquire the mutex without blocking, returning None if the mutex is currently locked.
Sourcepub unsafe fn force_unlock(&self)
pub unsafe fn force_unlock(&self)
Forces the mutex to be unlocked, even if it is currently locked.