Module syscalls

This module exposes SafaOS’s syscalls and their rust counterparts

Modules

fs
FS Operations related syscalls (that takes a path) such as create, remove, open, rename and etc
futex
(SysTFut) Futex related syscalls and operations
io
I/O Operations related syscalls (that takes a resource) such as read, write, truncate, etc
misc
Syscalls and operations that don’t fall into a specific category
process
(SysP) Process related syscalls and operations
process_misc
Syscalls and operations related to the current process
resources
(SysR) Resources related syscalls and operations such as destroying resources, duplicating them, etc
thread
(SysT) Thread related syscalls and operations
types
Contains documentation-only types for syscall arguments

Macros

syscall
Invokes a syscall with the given number and arguments Number must be of type [SyscallNum] Arguments must be of type usize returns a SyscallResult

Enums

SyscallNum
defines Syscall numbers