pub fn diriter_close(fd: Ri) -> Result<(), ErrorStatus>Expand description
Closes the directory iterator with the resource id fd
see sysdiriter_close for underlying syscall
pub fn diriter_close(fd: Ri) -> Result<(), ErrorStatus>Closes the directory iterator with the resource id fd
see sysdiriter_close for underlying syscall