pub fn fattrs(fd: Ri) -> Result<FileAttr, ErrorStatus>Expand description
Gets the file attributes of the file with the resource id fd
pub fn fattrs(fd: Ri) -> Result<FileAttr, ErrorStatus>Gets the file attributes of the file with the resource id fd