#[no_mangle]
pub extern "C" fn sysdiriter_open(
dir_ri: Ri,
dest_ri: RequiredPtrMut<Ri>,
) -> SyscallResultExpand description
Opens a directory iterator for the directory with the resource id dir_ri
#[no_mangle]
pub extern "C" fn sysdiriter_open(
dir_ri: Ri,
dest_ri: RequiredPtrMut<Ri>,
) -> SyscallResultOpens a directory iterator for the directory with the resource id dir_ri