#[no_mangle]
pub extern "C" fn sysdup(
ri: Ri,
dest_ri: RequiredPtrMut<Ri>,
) -> SyscallResultExpand description
Duplicates the resource referred to by the resource id ri and puts the new resource id in dest_ri
#[no_mangle]
pub extern "C" fn sysdup(
ri: Ri,
dest_ri: RequiredPtrMut<Ri>,
) -> SyscallResultDuplicates the resource referred to by the resource id ri and puts the new resource id in dest_ri