#[no_mangle]
pub extern "C" fn sysfsize(
fd: Ri,
dest_size: OptionalPtrMut<usize>,
) -> SyscallResultExpand description
Gets the size of the file with the resource id fd and puts it in dest_size
#[no_mangle]
pub extern "C" fn sysfsize(
fd: Ri,
dest_size: OptionalPtrMut<usize>,
) -> SyscallResultGets the size of the file with the resource id fd and puts it in dest_size