Function sysgetcwd

#[no_mangle]
pub extern "C" fn sysgetcwd(
    cwd_buf: StrPtrMut,
    cwd_buf_len: usize,
    dest_len: OptionalPtrMut<usize>,
) -> SyscallResult
Gets the current working directory and puts it in cwd_buf with length cwd_buf_len if dest_len is not null, it will be set to the length of the cwd if the cwd is too long to fit in cwd_buf, the syscall will return ErrorStatus::Generic (1) the cwd is currently maximumally 1024 bytes