#[no_mangle]
pub extern "C" fn sysread(
fd: Ri,
offset: isize,
buf: RequiredPtrMut<u8>,
len: usize,
dest_read: OptionalPtrMut<usize>,
) -> SyscallResultExpand description
Reads len bytes from the file with the resource id fd at offset offset into buf
if dest_read is not null, it will be set to the number of bytes read