#[no_mangle]
pub extern "C" fn syssbrk(
size: isize,
target_ptr: OptionalPtrMut<*mut u8>,
) -> SyscallResultExpand description
Increases the range of the process’s data break by size bytes and puts the new break pointer in target_ptr
#[no_mangle]
pub extern "C" fn syssbrk(
size: isize,
target_ptr: OptionalPtrMut<*mut u8>,
) -> SyscallResultIncreases the range of the process’s data break by size bytes and puts the new break pointer in target_ptr