#[no_mangle]
pub extern "C" fn systruncate(fd: Ri, len: usize) -> SyscallResultExpand description
Truncates the file with the resource id fd to len bytes
#[no_mangle]
pub extern "C" fn systruncate(fd: Ri, len: usize) -> SyscallResultTruncates the file with the resource id fd to len bytes