Module fs

Module fs 

FS Operations related syscalls (that takes a path) such as create, remove, open, rename and etc

Functions

create
Creates the file with the path path
createdir
Creates the directory with the path path
getdirentry
open
Opens the file with the path path with a given mode (permissions and flags), returns the resource id of the file descriptor
open_all
Opens the path path and returns the resource id of the file descriptor, with all permissions
remove_path
Removes a given path
syscreate_dir
Creates the directory with the path path
syscreate_file
Creates the file with the path path path must be valid utf-8
sysgetdirentry
Gets the directory entry for the path path and puts it in dest_direntry path must be valid utf-8 if dest_direntry is not null, it will be set to the directory entry
sysopen
Opens the file with the path path and puts the resource id in dest_fd, with a given mode (permissions and flags)
sysopen_all
Opens the file with the path path and puts the resource id in dest_fd, with all permissions
sysremove_path
Deletes “removes” a given path