pub fn open_all(path: &str) -> Result<Ri, ErrorStatus>Expand description
Opens the path path and returns the resource id of the file descriptor, with all permissions
see sysopen_all for underlying syscall
pub fn open_all(path: &str) -> Result<Ri, ErrorStatus>Opens the path path and returns the resource id of the file descriptor, with all permissions
see sysopen_all for underlying syscall