#[no_mangle]
pub extern "C" fn sysopen_all(
path: Str,
dest_fd: RequiredPtr<Ri>,
) -> SyscallResultExpand description
Opens the file with the path path and puts the resource id in dest_fd, with all permissions
path must be valid utf-8
#[no_mangle]
pub extern "C" fn sysopen_all(
path: Str,
dest_fd: RequiredPtr<Ri>,
) -> SyscallResultOpens the file with the path path and puts the resource id in dest_fd, with all permissions
path must be valid utf-8