Module futex

Module futex 

(SysTFut) Futex related syscalls and operations

Functions

futex_wait
Waits for *addr to not be equal to val only stops waiting if *addr != val and signaled by futex_wake or timeout is reached
futex_wake
Wakes up, up to n threads waiting on futex addr using futex_wait
syst_fut_wait
Waits for *addr to not be equal to val only stops waiting if *addr != val and signaled by syst_fut_wake or timeout is reached
syst_fut_wake
Wakes up, up to n threads waiting on futex addr using syst_fut_wait