futex_wake

Function futex_wake 

pub fn futex_wake(addr: &AtomicU32, n: usize) -> Result<usize, ErrorStatus>
Wakes up, up to n threads waiting on futex addr using futex_wait

returns the amount of threads that were woken up on success

Safety

This function is safe because the value at addr is not accessed unless there were another thread waiting on it using futex_wait