pub fn diriter_next(dir_ri: Ri) -> Result<DirEntry, ErrorStatus>Expand description
Gets the next directory entry from a directory iterator,
see sysdiriter_next for underlying syscall
pub fn diriter_next(dir_ri: Ri) -> Result<DirEntry, ErrorStatus>Gets the next directory entry from a directory iterator,
see sysdiriter_next for underlying syscall