diriter_open

Function diriter_open 

pub fn diriter_open(dir_ri: Ri) -> Result<Ri, ErrorStatus>
Opens a directory iterator for the directory with the resource id dir_ri, returns the resource id of the directory iterator

see sysdiriter_open for underlying syscall