Function write

pub fn write(fd: Ri, offset: isize, buf: &[u8]) -> Result<usize, ErrorStatus>
Writes buf.len() bytes from buf to the file with the resource id fd at offset offset and returns the number of bytes written