Module process

Module process 

(SysP) Process related syscalls and operations

Functions

exit
Exits the process with the exit code code
spawn
same as unsafe_spawn but safe because it makes it clear that argv are consumed
sysp_exit
Exits the process with the exit code [code]
sysp_spawn_inner
sysp_try_cleanup
Attempts to cleanup the process with pid pid and returns it’s exit status on success
sysp_wait
Waits for a child process with the pid pid to exit
try_cleanup
Attempts to cleanup the process with pid pid and returns it’s exit status on success
unsafe_spawn
spawns a new process
wait
Waits for the process with the resource id pid to exit and returns the exit code of the process