#[unsafe(no_mangle)]pub extern "C" fn sysp_try_cleanup(
pid: Pid,
dest_exit_code: OptionalPtrMut<usize>,
) -> SyscallResultExpand description
Attempts to cleanup the process with pid pid and returns it’s exit status on success
Returns
-
ErrorStatus::InvalidPidif the target process doesn’t exist at the time of attempted cleanup -
ErrorStatus::Genericif the target process isn’t dead and awaiting cleanup