#[no_mangle]
pub extern "C" fn sysp_wait(
pid: Pid,
exit_code: OptionalPtrMut<usize>,
) -> SyscallResultExpand description
Waits for a child process with the pid pid to exit
Returns
-
ErrorStatus::InvalidPidif the target process doesn’t exist at the time of wait -
ErrorStatus::MissingPermissionsif the target process isn’t a child of self -
if
exit_codeis not null, it will be set to the exit code of the process if successful