pub fn try_cleanup(pid: Pid) -> Result<Option<usize>, ErrorStatus>Expand description
Attempts to cleanup the process with pid pid and returns it’s exit status on success
Returns
- Err(
ErrorStatus::InvalidPid) if the target process doesn’t exist at the time of attempted cleanup - Ok(None) if the target process isn’t dead and awaitng cleanup
- Ok(Some(exit_code)) if successful