pub unsafe fn unsafe_spawn(
name: Option<&str>,
path: &str,
args: *mut [&str],
flags: SpawnFlags,
priority: RawContextPriority,
stdin: Option<Ri>,
stdout: Option<Ri>,
stderr: Option<Ri>,
custom_stack_size: Option<NonZero<usize>>,
) -> Result<Pid, ErrorStatus>Expand description
spawns a new process
Arguments
stdin,stdout,stderrare the file descriptors of stdio, if None, they will be inherited from the parentpriorityis the process’s default priority (that the threads, including the root one, will inherit by default), if set to None the behavior isn’t well defined, however for now it will default to a constant value
Safety
-
argvmust be valid pointers to a slice of slices of&str -
argvwill become invalid after use, using them is UB