pub fn wait(pid: Pid) -> Result<usize, ErrorStatus>Expand description
Waits for the process with the resource id pid to exit
and returns the exit code of the process
Returns
-
Ok(exit_code) if the target process was found, was a child of self, and was awaited successfully
-
ErrorStatus::InvalidPidif the target process doesn’t exist at the time of wait -
ErrorStatus::MissingPermissionsif the target process isn’t a child of self