Module process_misc

Module process_misc 

Syscalls and operations related to the current process

Functions

chdir
Changes the current work dir to path
getcwd
Retrieves the current work dir
syschdir
Changes the current working directory to the path buf with length buf_len (expects given buffer to be utf-8)
sysgetcwd
Gets the current working directory and puts it in cwd_buf with length cwd_buf_len if dest_len is not null, it will be set to the length of the cwd if the cwd is too long to fit in cwd_buf, the syscall will return ErrorStatus::Generic (1) the cwd is currently maximumally 1024 bytes