spawn3

Function spawn3 

pub fn spawn3(
    entry_point: fn(thread_id: Cid) -> !,
    priority: RawContextPriority,
    custom_stack_size: Option<NonZero<usize>>,
) -> Result<Cid, ErrorStatus>
Spawns a thread as a child of self unlike spawn, this will pass no arguments to the thread

Arguments

  • entry_point: a pointer to the main function of the thread

  • priotrity: the pritority of the thread in the thread queue, will default to the parent’s

Returns

  • the thread ID of the spawned thread