syst_exit

Function syst_exit 

#[unsafe(no_mangle)]
pub extern "C" fn syst_exit(code: usize) -> !
Exits the current thread, threads don’t have an exit code however if the thread was the last thread in the process, then the process will exit with code [code]