#[unsafe(no_mangle)]pub extern "C" fn syst_wait(cid: Cid) -> SyscallResultExpand description
Waits for a child thread with the cid cid to exit
Returns
ErrorStatus::InvalidTidif thread doesn’t exist at the time of wait
#[unsafe(no_mangle)]pub extern "C" fn syst_wait(cid: Cid) -> SyscallResultWaits for a child thread with the cid cid to exit
ErrorStatus::InvalidTid if thread doesn’t exist at the time of wait