pub fn wait(cid: Cid) -> Result<(), ErrorStatus>Expand description
Waits for the thread with the id cid to exit
Returns
ErrorStatus::InvalidTidif the target thread doesn’t exist at the time of wait
pub fn wait(cid: Cid) -> Result<(), ErrorStatus>Waits for the thread with the id cid to exit
ErrorStatus::InvalidTid if the target thread doesn’t exist at the time of wait