Module types

Contains documentation-only types for syscall arguments

Structs

SyscallResult
An opaque type that represents a syscall result the underlying type is a 16 bit unsigned integer, in which 0 is success and any other value is in error represented by the ErrorStatus enum

Type Aliases

Cid
A thread ID
OptionalPtr
A nullable imuttable pointer to T
OptionalPtrMut
A nullable muttable pointer to T
OptionalStr
An optional immuttable nullable utf8 byte slice
OptionalStrMut
An optional muttable nullable utf8 byte slice
Pid
A process ID
RequiredPtr
An immuttable pointer to T
RequiredPtrMut
A muttable pointer to T
Ri
A resource id this is a generic type that can be used to represent any resource (file, directory, device, directory iterator, etc.)