pub type OptionalPtrMut<T> = OptZero<RequiredPtrMut<T>>;Expand description
A nullable muttable pointer to T
guaranteed to be accepted by the syscall if it is null,
however the syscall will return ErrorStatus::InvalidPtr if it is not aligned to align_of::<T>()
this is typically for the syscall to return optional values
Aliased Type
pub struct OptionalPtrMut<T>(/* private fields */);