Type Alias OptionalStrPtr

pub type OptionalStrPtr = OptionalPtr<u8>;
An optional immuttable nullable pointer to a byte array

the syscall will return [ErrorStatus::InvaildStr] if it is not null and is not valid utf-8

typically followed by a len parameter to specify the length of the string

can be null