pub type RequiredPtr<T> = *const T;Expand description
An immuttable pointer to T
the syscall will return ErrorStatus::InvalidPtr if it is not aligned to align_of::<T>() or if it is null
typically used for the syscall to return a value
pub type RequiredPtr<T> = *const T;An immuttable pointer to T
the syscall will return ErrorStatus::InvalidPtr if it is not aligned to align_of::<T>() or if it is null
typically used for the syscall to return a value