pub type RequiredPtrMut<T> = *mut T;Expand description
A muttable pointer to T
the syscall will return ErrorStatus::InvalidPtr if it is not aligned to align_of::<T>() or if it is null
typically used for the syscall to return a value
pub type RequiredPtrMut<T> = *mut T;A muttable pointer to T
the syscall will return ErrorStatus::InvalidPtr if it is not aligned to align_of::<T>() or if it is null
typically used for the syscall to return a value