pub struct ShouldNotBeZero<T>(/* private fields */)
where
T: ZeroableThing;Expand description
Describes something that is valid when passed as a zero but SHOULDN’T BE a zero
mainly for usage with FFI and OptZero so that if it was passed as a zero it would be treated as a None value
Implementations
Sourceimpl<T> ShouldNotBeZero<T>where
T: ZeroableThing,
impl<T> ShouldNotBeZero<T>where
T: ZeroableThing,
pub fn new(value: T) -> Option<ShouldNotBeZero<T>>
pub const unsafe fn new_unchecked(value: T) -> ShouldNotBeZero<T>
pub const fn value_ref(&self) -> &T
Sourceimpl<T> ShouldNotBeZero<T>where
T: ZeroableThing + Copy,
impl<T> ShouldNotBeZero<T>where
T: ZeroableThing + Copy,