Module for process-related high-level functions over process related syscalls
Such as api initialization functions init::_c_api_init and init::sysapi_init, environment variables, and process arguments
FIXME: this module should not be used when std feature is enabled, as it conflicts with the standard library’s api dependency
I should probably hide this when std feature is enabled.
Modules
- args
- Wrapper around the arguments passed to the program.
api should be initialized before use see
super::init - env
- contains functions related to environment variables,
api must be initialized before using these functions, see
super::init - init
- contains api initialization functions, that should be called before using the api
- stdio
- contains functions related to standard input/output/error streams descriptors
api must be initialized before using these functions, see
super::init