Module for process-related high-level functions over process related syscalls
Such as api initialization functions _c_api_init and sysapi_init, environment variables, and process arguments
Structs
- Args
Iter - An iterator over the arguments passed to the program.
Functions
- _c_
api_ ⚠init - Initializes the safa-api, converts arguments to C-style arguments, calls
main, and exits with the result main are designed as C main function, - env_
clear - env_get
- env_
get_ all - Gets all the environment variables in the current process
- env_
remove - env_set
- meta_
take - sysapi_
init - Initializes the safa-api
- sysenv_
clear - Clear all environment variables.
- sysenv_
get - Get an environment variable by key.
- sysenv_
remove - Remove an environment variable by key.
- sysenv_
set - Set an environment variable by key.
- sysget_
arg - Get the argument at the given index.
- sysget_
argc - Get the number of arguments passed to the program.
- sysmeta_
stderr - Returns the resource id of the stderr file descriptor
- sysmeta_
stdin - Returns the resource id of the stdin file descriptor
- sysmeta_
stdout - Returns the resource id of the stdout file descriptor
- sysmeta_
take - Takes ownership of the task metadata
the task metadata is used to store the stdin, stdout, and stderr file descriptors
this syscall can only be called once otherwise it will return
ErrorStatus::Generic(1)