Module process

Functions

meta_take
sysmeta_stderr
Returns the resource id of the stderr file descriptor
sysmeta_stdin
Returns the resource id of the stdin file descriptor
sysmeta_stdout
Returns the resource id of the stdout file descriptor
sysmeta_take
Takes ownership of the task metadata the task metadata is used to store the stdin, stdout, and stderr file descriptors this syscall can only be called once otherwise it will return ErrorStatus::Generic (1)