Functions
- meta_
take - sysmeta_
stderr - Returns the resource id of the stderr file descriptor
- sysmeta_
stdin - Returns the resource id of the stdin file descriptor
- sysmeta_
stdout - Returns the resource id of the stdout file descriptor
- sysmeta_
take - Takes ownership of the task metadata
the task metadata is used to store the stdin, stdout, and stderr file descriptors
this syscall can only be called once otherwise it will return
ErrorStatus::Generic(1)