Wrapper around the arguments passed to the program.
api should be initialized before use see super::init
Structs
- Args
Iter - An iterator over the arguments passed to the program.
Functions
- sysget_
arg - Get the argument at the given index.
- sysget_
argc - Get the number of arguments passed to the program.