contains functions related to environment variables,
api must be initialized before using these functions, see super::init
Functions
- env_
clear - env_get
- env_
get_ all - Gets all the environment variables in the current process
- env_
remove - env_set
- sysenv_
clear - Clear all environment variables.
- sysenv_
get - Get an environment variable by key.
- sysenv_
remove - Remove an environment variable by key.
- sysenv_
set - Set an environment variable by key.