#[unsafe(no_mangle)]pub unsafe extern "C" fn sysenv_get(
key: OptZero<Slice<u8>>,
) -> OptZero<Slice<u8>>Expand description
Get an environment variable by key.
Safety
unsafe because it returns a pointer to the environment variable, which may be invalid after the environment is modified.