#[no_mangle]
pub extern "C" fn sysmeta_take(
dest_task: *mut TaskMetadata,
) -> SyscallResultExpand description
Takes ownership of the task metadata
the task metadata is used to store the stdin, stdout, and stderr file descriptors
this syscall can only be called once otherwise it will return ErrorStatus::Generic (1)