Function _c_api_init

#[no_mangle]
pub unsafe extern "C" fn _c_api_init(
    args: RawSliceMut<NonNullSlice<u8>>,
    env: RawSliceMut<NonNullSlice<u8>>,
    task_abi_structures: *const AbiStructures,
    main: extern "C" fn(argc: i32, argv: *const *const u8) -> i32,
) -> !
Initializes the safa-api, converts arguments to C-style arguments, calls main, and exits with the result main are designed as C main function,

this function is designed to be called from C code at _start before main, main should be passed as a parameter