contains functions related to standard input/output/error streams descriptors
api must be initialized before using these functions, see super::init
Functions
- init_
meta - sysget_
stderr - Returns the resource id of the stderr file descriptor
- sysget_
stdin - Returns the resource id of the stdin file descriptor
- sysget_
stdout - Returns the resource id of the stdout file descriptor
- systry_
get_ stderr - Returns the resource id of the stderr file descriptor (if available)
- systry_
get_ stdin - Returns the resource id of the stdin file descriptor (if available)
- systry_
get_ stdout - Returns the resource id of the stdout file descriptor (if available)