contains functions related to standard input/output/error streams descriptors
api must be initialized before using these functions, see super::init
Functions
- init_
meta - sysmeta_
stderr - Returns the resource id of the stderr file descriptor
- sysmeta_
stdin - Returns the resource id of the stdin file descriptor
- sysmeta_
stdout - Returns the resource id of the stdout file descriptor