Module stdio

contains functions related to standard input/output/error streams descriptors api must be initialized before using these functions, see super::init

Functions

init_meta
sysmeta_stderr
Returns the resource id of the stderr file descriptor
sysmeta_stdin
Returns the resource id of the stdin file descriptor
sysmeta_stdout
Returns the resource id of the stdout file descriptor