pub struct OpenOptions(/* private fields */);Expand description
Describes the options for opening a file or directory.
Implementations
Sourceimpl OpenOptions
impl OpenOptions
Sourcepub const WRITE: OpenOptions
pub const WRITE: OpenOptions
Open the file for writing.
Sourcepub const READ: OpenOptions
pub const READ: OpenOptions
Open the file for reading.
Sourcepub const CREATE_FILE: OpenOptions
pub const CREATE_FILE: OpenOptions
Create the file if it does not exist.
Sourcepub const CREATE_DIRECTORY: OpenOptions
pub const CREATE_DIRECTORY: OpenOptions
Create the directory if it does not exist. (doesn’t create parent directories)
Sourcepub const WRITE_TRUNCATE: OpenOptions
pub const WRITE_TRUNCATE: OpenOptions
Truncate the file to zero length if it already exists.
pub const fn from_bits(bits: u8) -> OpenOptions
pub const fn contains(self, other: OpenOptions) -> bool
pub const fn is_write(&self) -> bool
pub const fn is_write_truncate(&self) -> bool
pub const fn is_read(&self) -> bool
pub const fn create_file(&self) -> bool
pub const fn create_dir(&self) -> bool