ABI structures are structures that are passed to tasks by the parent task
for now only stdio file descriptors are passed
you get a pointer to them in the r8 register at _start (the 5th argument)
configuration for the thread spawn syscall
for now it takes only a single argument pointer which is a pointer to an optional argument, that pointer is going to be passed to the thread as the second argument