#[repr(C)]pub struct AbiStructures {
pub stdio: TaskStdio,
}Expand description
ABI structures are structures that are passed to tasks by the parent task
for now only stdio file descriptors are passed
you get a pointer to them in the r8 register at _start (the 5th argument)
Fields
stdio: TaskStdioTrait Implementations
Sourceimpl Clone for AbiStructures
impl Clone for AbiStructures
Sourcefn clone(&self) -> AbiStructures
fn clone(&self) -> AbiStructures
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbiStructures
impl Debug for AbiStructures
Sourceimpl Default for AbiStructures
impl Default for AbiStructures
Sourcefn default() -> AbiStructures
fn default() -> AbiStructures
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for AbiStructures
impl PartialEq for AbiStructures
impl Copy for AbiStructures
impl Eq for AbiStructures
impl StructuralPartialEq for AbiStructures