#[repr(C)]pub struct TSpawnConfig {
pub revision: u32,
pub argument_ptr: *const (),
pub priority: Optional<ContextPriority>,
pub cpu: Optional<usize>,
}Expand description
configuration for the thread spawn syscall for now it takes only a single argument pointer which is a pointer to an optional argument, that pointer is going to be passed to the thread as the second argument
Fields
revision: u32argument_ptr: *const ()priority: Optional<ContextPriority>cpu: Optional<usize>The index of the CPU to append to, if it is None the kernel will choose one, use 0 for the boot CPU
Implementations
Sourceimpl TSpawnConfig
impl TSpawnConfig