Struct RawSlice

#[repr(C)]
pub struct RawSlice<T> { /* private fields */ }
A C compatible slice of type T

Implementations

Source

impl<T> RawSlice<T>

pub unsafe fn from_raw_parts(ptr: *const T, len: usize) -> RawSlice<T>

pub unsafe fn from_slice(slice: &[T]) -> RawSlice<T>

pub fn len(&self) -> usize

pub fn as_ptr(&self) -> *const T

pub unsafe fn into_slice<'a>(self) -> Option<&'a [T]>

Converts a RawSlice<T> into a slice of type T

returns None if the slice ptr is null or the length is zero

Safety

panics if the slice ptr is not aligned to the alignment of T