Struct RawSliceMut

#[repr(C)]
pub struct RawSliceMut<T> { /* private fields */ }

Implementations

Source

impl<T> RawSliceMut<T>

pub unsafe fn from_raw_parts(ptr: *mut T, len: usize) -> Self

pub fn len(&self) -> usize

pub fn as_ptr(&self) -> *const T

pub fn as_mut_ptr(&self) -> *mut T

Source

impl<T> RawSliceMut<RawSlice<T>>

pub unsafe fn from_slices(slices: *mut [&[T]]) -> Self

Converts a slice of slices of [T] into RawSliceMut<RawSlice<T>>

Safety

slices becomes invaild after use as it is going to be reused as a memory location for creating Self making this unexpensive but dangerous O(N) expect if the Layout of RawSlice is equal to the Layout of rust slices, and it has been optimized it is O(1)