#[repr(C)]pub struct RawSliceMut<T> { /* private fields */ }Implementations
Sourceimpl<T> RawSliceMut<T>
impl<T> RawSliceMut<T>
Sourceimpl<T> RawSliceMut<RawSlice<T>>
impl<T> RawSliceMut<RawSlice<T>>
Sourcepub unsafe fn from_slices(slices: *mut [&[T]]) -> Self
pub unsafe fn from_slices(slices: *mut [&[T]]) -> Self
Converts a slice of slices of [T] into RawSliceMut<RawSlice<T>>
Safety
slices becomes invaild after use
as it is going to be reused as a memory location for creating Self
making this unexpensive but dangerous
O(N) expect if the Layout of RawSlice is equal to the Layout of rust slices, and it has been optimized it is O(1)