pub fn dup(ri: Ri) -> Result<Ri, ErrorStatus>Expand description
Duplicates the resource refered to by the resource id ri
and returns the new resource id
pub fn dup(ri: Ri) -> Result<Ri, ErrorStatus>Duplicates the resource refered to by the resource id ri
and returns the new resource id