Function sysdup

#[no_mangle]
pub extern "C" fn sysdup(
    ri: Ri,
    dest_ri: RequiredPtrMut<Ri>,
) -> SyscallResult
Duplicates the resource refered to by the resource id ri and puts the new resource id in dest_ri