Function sysgetdirentry

#[no_mangle]
pub extern "C" fn sysgetdirentry(
    path_ptr: StrPtr,
    path_len: usize,
    dest_direntry: OptionalPtrMut<DirEntry>,
) -> SyscallResult
Gets the directory entry for the path path and puts it in dest_direntry path must be valid utf-8 if dest_direntry is not null, it will be set to the directory entry