#[no_mangle]
pub extern "C" fn syswait(
pid: Pid,
exit_code: *mut usize,
) -> SyscallResultExpand description
Waits for the process with the resource id pid to exit
if exit_code is not null, it will be set to the exit code of the process