Function syswrite

#[no_mangle]
pub extern "C" fn syswrite(
    fd: Ri,
    offset: isize,
    buf: RequiredPtr<u8>,
    len: usize,
    dest_wrote: OptionalPtrMut<usize>,
) -> SyscallResult
Writes len bytes from buf to the file with the resource id fd at offset offset

if dest_wrote is not null, it will be set to the number of bytes written