pub fn wait(pid: Pid) -> Result<usize, ErrorStatus>Expand description
Waits for the process with the resource id pid to exit
and returns the exit code of the process
will return 0 as an exit code if process wasn’t found
pub fn wait(pid: Pid) -> Result<usize, ErrorStatus>Waits for the process with the resource id pid to exit
and returns the exit code of the process
will return 0 as an exit code if process wasn’t found