FS Operations related syscalls (that takes a path) such as create, remove, open, rename and etc
Functions
- create
- Creates the file with the path
path - createdir
- Creates the directory with the path
path - getdirentry
- open
- Opens the file with the path
pathwith a given mode (permissions and flags), returns the resource id of the file descriptor - open_
all - Opens the path
pathand returns the resource id of the file descriptor, with all permissions - remove_
path - Removes a given path
- syscreate_
dir - Creates the directory with the path
path - syscreate_
file - Creates the file with the path
pathpath must be valid utf-8 - sysgetdirentry
- Gets the directory entry for the path
pathand puts it indest_direntrypath must be valid utf-8 ifdest_direntryis not null, it will be set to the directory entry - sysopen
- Opens the file with the path
pathand puts the resource id indest_fd, with a given mode (permissions and flags) - sysopen_
all - Opens the file with the path
pathand puts the resource id indest_fd, with all permissions - sysremove_
path - Deletes “removes” a given path