#[unsafe(no_mangle)]pub extern "C" fn sysgetdirentry(
path: Str,
dest_direntry: OptionalPtrMut<DirEntry>,
) -> SyscallResultExpand description
Gets the directory entry for the path path and puts it in dest_direntry
path must be valid utf-8
if dest_direntry is not null, it will be set to the directory entry