I/O Operations related syscalls (that takes a resource) such as read, write, truncate, etc
Functions
- diriter_
next - Gets the next directory entry from a directory iterator,
- diriter_
open - Opens a directory iterator for the directory with the resource id
dir_ri, returns the resource id of the directory iterator - fattrs
- Gets the file attributes of the file with the resource id
fd - fsize
- Gets the size of the file with the resource id
fd - read
- Reads
buf.len()bytes from the file with the resource idfdat offsetoffsetintobuf - sync
- Syncs the resource with the resource id
ri - sysdiriter_
next - Gets the next directory entry from a directory iterator,
- sysdiriter_
open - Opens a directory iterator for the directory with the resource id
dir_ri - sysfattrs
- Gets the file attributes of the file with the resource id
fdand puts them indest_attrs - sysfsize
- Gets the size of the file with the resource id
fdand puts it indest_size - sysread
- Reads
lenbytes from the file with the resource idfdat offsetoffsetintobuf - syssync
- Syncs the resource with the resource id
fd - systruncate
- Truncates the file with the resource id
fdtolenbytes - syswrite
- Writes
lenbytes frombufto the file with the resource idfdat offsetoffset - truncate
- Truncates the file with the resource id
fdtolenbytes - write
- Writes
buf.len()bytes frombufto the file with the resource idfdat offsetoffsetand returns the number of bytes written