#[unsafe(no_mangle)]pub extern "C" fn sysfattrs(
fd: Ri,
dest_attrs: OptionalPtrMut<FileAttr>,
) -> SyscallResultExpand description
Gets the file attributes of the file with the resource id fd and puts them in dest_attrs
#[unsafe(no_mangle)]pub extern "C" fn sysfattrs(
fd: Ri,
dest_attrs: OptionalPtrMut<FileAttr>,
) -> SyscallResultGets the file attributes of the file with the resource id fd and puts them in dest_attrs