(SysP) Process related syscalls and operations
Functions
- exit
- Exits the process with the exit code
code - spawn
- same as
unsafe_spawnbut safe because it makes it clear thatargvare consumed - sysp_
exit - Exits the process with the exit code [
code] - sysp_
spawn_ inner - sysp_
try_ cleanup - Attempts to cleanup the process with pid
pidand returns it’s exit status on success - sysp_
wait - Waits for a child process with the pid
pidto exit - try_
cleanup - Attempts to cleanup the process with pid
pidand returns it’s exit status on success - unsafe_
spawn ⚠ - spawns a new process
- wait
- Waits for the process with the resource id
pidto exit and returns the exit code of the process