Module process

(SysP) Process related syscalls and operations

Functions

exit
Exits the process with the exit code code
spawn
same as unsafe_spawn but safe because it makes it clear that argv are consumed
sysp_exit
Exits the process with the exit code [code]
sysp_wait
Waits for a child process with the pid pid to exit
unsafe_spawn
spawns a new process
wait
Waits for the process with the resource id pid to exit and returns the exit code of the process