Syscalls and operations related to the current process
Functions
- chdir
- Changes the current work dir to
path - getcwd
- Retrieves the current work dir
- sbrk
- Increases the range of the process’s data break by
sizebytes returns the new break pointer - syschdir
- Changes the current working directory to the path
bufwith lengthbuf_len(expects given buffer to be utf-8) - sysgetcwd
- Gets the current working directory and puts it in
cwd_bufwith lengthcwd_buf_lenifdest_lenis not null, it will be set to the length of the cwd if the cwd is too long to fit incwd_buf, the syscall will returnErrorStatus::Generic(1) the cwd is currently maximumally 1024 bytes - syssbrk
- Increases the range of the process’s data break by
sizebytes and puts the new break pointer intarget_ptr