#[no_mangle]
pub extern "C" fn syschdir(buf: Str) -> SyscallResultExpand description
Changes the current working directory to the path buf with length buf_len
(expects given buffer to be utf-8)
#[no_mangle]
pub extern "C" fn syschdir(buf: Str) -> SyscallResultChanges the current working directory to the path buf with length buf_len
(expects given buffer to be utf-8)