#[no_mangle]
pub extern "C" fn sysyield() -> SyscallResultExpand description
Switches to the next thread in the thread queue of the current CPU
#[no_mangle]
pub extern "C" fn sysyield() -> SyscallResultSwitches to the next thread in the thread queue of the current CPU