Contains documentation-only types for syscall arguments
Structs
- Syscall
Result - An opaque type that represents a syscall result
the underlying type is a 16 bit unsigned integer, in which 0 is success and any other value is in error
respresented by the
ErrorStatusenum
Type Aliases
- Optional
Ptr - A nullable imuttable pointer to
T - Optional
PtrMut - A nullable muttable pointer to
T - Optional
StrPtr - An optional immuttable nullable pointer to a byte array
- Pid
- A process id
- Required
Ptr - An immuttable pointer to
T - Required
PtrMut - A muttable pointer to
T - Ri
- A resource id this is a generic type that can be used to represent any resource (file, directory, device, directory iterator, etc.)
- StrPtr
- An immuttable pointer to a byte array
- StrPtr
Mut - A muttable pointer to a byte array