Module types

Contains documentation-only types for syscall arguments

Structs

SyscallResult
An opaque type that represents a syscall result the underlying type is a 16 bit unsigned integer, in which 0 is success and any other value is in error respresented by the ErrorStatus enum

Type Aliases

OptionalPtr
A nullable imuttable pointer to T
OptionalPtrMut
A nullable muttable pointer to T
OptionalStrPtr
An optional immuttable nullable pointer to a byte array
Pid
A process id
RequiredPtr
An immuttable pointer to T
RequiredPtrMut
A muttable pointer to T
Ri
A resource id this is a generic type that can be used to represent any resource (file, directory, device, directory iterator, etc.)
StrPtr
An immuttable pointer to a byte array
StrPtrMut
A muttable pointer to a byte array