Type Alias OptionalStrMut

pub type OptionalStrMut = OptZero<Str>;
An optional muttable nullable utf8 byte slice

the syscall will return ErrorStatus::InvalidStr if it is not null and is not valid utf-8

typically followed by a len parameter to specify the length of the string

can be null

Aliased Type

pub struct OptionalStrMut(/* private fields */);