pub type StrPtrMut = RequiredPtrMut<u8>;Expand description
A muttable pointer to a byte array
the syscall will return [ErrorStatus::InvaildPtr] if it is null
typically used for the syscall to return a string meaning that after the syscall is successful it should contain a valid utf-8 string
typically followed by a len parameter to specify the length of the string